DeviceClient

Struct DeviceClient 

pub struct DeviceClient<C>
where C: Connection,
{ /* private fields */ }
Client to send and receive message to and form Astarte or access the Device properties.

Notes

Cloning the client will not broadcast the DeviceEvent. Each message can only be received once.

Implementations

Source

impl<S> DeviceClient<Mqtt<S>>

pub async fn get_cert_expiry(&self) -> Option<DateTime<Utc>>

Retrieve the expiry (not_after) timestamp of the current certificate

pub async fn is_valid_at(&self, check_dt: DateTime<Utc>) -> Option<bool>

Retrieve the expiry (not_after) timestamp of the current certificate Note that this function will log a security event if the feature is enabled when the certificate will expire at the passed datetime