#[non_exhaustive]pub enum Error {
Show 18 variants
ConnectionTimeout,
Interface(Error),
AddInterface(AddInterfaceError),
InterfaceNotFound {
name: String,
},
MappingNotFound {
interface: String,
mapping: String,
},
InvalidEndpoint(MappingPathError),
Types(TypeError),
Properties(PropertiesError),
Store(StoreError),
Validation(UserValidationError),
Aggregation(AggregationError),
InterfaceType(InterfaceTypeError),
Builder(BuilderError),
Mqtt(MqttError),
Disconnected,
Retention(RetentionError),
Session(SessionError),
Grpc(GrpcError),
}Expand description
Astarte error.
Possible errors returned by functions of the Astarte device SDK.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConnectionTimeout
The connection poll reached the max number of retries.
Interface(Error)
Error while parsing interface.
AddInterface(AddInterfaceError)
Error while operating on the device introspection.
InterfaceNotFound
Couldn’t find an interface with the given name.
MappingNotFound
Couldn’t find missing mapping in the interface.
InvalidEndpoint(MappingPathError)
Couldn’t parse the mapping path.
Types(TypeError)
Errors when converting between Astarte types.
Properties(PropertiesError)
Error while parsing the /control/consumer/properties payload.
Store(StoreError)
Error returned by a store operation.
Validation(UserValidationError)
Send or receive validation failed
Aggregation(AggregationError)
Invalid aggregation between the interface and the data.
InterfaceType(InterfaceTypeError)
Invalid interface type between the interface and the data.
Builder(BuilderError)
Couldn’t build the device connection and client
Mqtt(MqttError)
Error returned by the MQTT connection.
Disconnected
Error when the Device is disconnected from Astarte or client.
This is an unrecoverable error for the SDK.
Retention(RetentionError)
Retention operation failed.
Session(SessionError)
Persistent session operation failed
Grpc(GrpcError)
message-hub only.Error returned by the gRPC transport